### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [1.0.1](https://github.com/hemna/aprsd-admin-extension/compare/1.0.0...1.0.1)

> 6 January 2025

- switch to readme.md [`9818c45`](https://github.com/hemna/aprsd-admin-extension/commit/9818c45ce31df7a0c6ef6e580cee765685f584ff)
- removed items from readme.md [`aea4c2a`](https://github.com/hemna/aprsd-admin-extension/commit/aea4c2a8fe6f6206964db062add50b1100e01d9a)
- Updated README [`af19912`](https://github.com/hemna/aprsd-admin-extension/commit/af19912702d6470c9124ae1ffaa70391c3631b90)
- updated README [`699d216`](https://github.com/hemna/aprsd-admin-extension/commit/699d21669f49768dbcc56bbe78cc245011394f21)
- some minor cleanup [`36dfed5`](https://github.com/hemna/aprsd-admin-extension/commit/36dfed528d935e4fff286e55dd15daa4cf3ca311)
- added screenshot [`650ab99`](https://github.com/hemna/aprsd-admin-extension/commit/650ab99fd8bdb3364469bfd0ef1596f52d8a41bd)
- Updated version string in ui. [`3965d26`](https://github.com/hemna/aprsd-admin-extension/commit/3965d2679ee08ddf7cb3232ea8bcdb011f9cca7e)

#### 1.0.0

> 3 January 2025

- Initial commit [`fc49393`](https://github.com/hemna/aprsd-admin-extension/commit/fc493938638ad9ae717021664edd63f2f809e70c)
- Initial commit of the admin web UI [`b11cc3c`](https://github.com/hemna/aprsd-admin-extension/commit/b11cc3c550cf59e84607c52258b632d38ae42c43)
- Got content working again [`b023397`](https://github.com/hemna/aprsd-admin-extension/commit/b0233978c44ab5b3ca0787254281abcc9aa985a1)
- deleted pyc file [`6d30868`](https://github.com/hemna/aprsd-admin-extension/commit/6d30868f7370ecd45e5b813f14e6433fcfde65bc)
- updated pre-commit hooks. [`f8a315d`](https://github.com/hemna/aprsd-admin-extension/commit/f8a315dfd27d362d309126fbec8a19e610805fcc)
- Update Makefile for changelog [`72b5b0a`](https://github.com/hemna/aprsd-admin-extension/commit/72b5b0a9b3f164188872cf64eecb9d73e088b4cd)
- Updated README [`fe45bb2`](https://github.com/hemna/aprsd-admin-extension/commit/fe45bb2de817ffc114f38c8838870c91aa9cfcd9)
